get_rand_attrs: Convenience function to get attributes for lists of random...

View source: R/analysis_random_graphs.R

get_rand_attrsR Documentation

Convenience function to get attributes for lists of random graphs

Description

Convenience function to get attributes for lists of random graphs

Usage

get_rand_attrs(bg.list, level)

Arguments

bg.list

A brainGraphList object, created in analysis_random_graphs

Value

A data.table


brainGraph documentation built on April 30, 2026, 9:07 a.m.