Learn R Programming

brainGraph (version 0.55.0)

rich.club.norm: Calculate the normalized rich club coefficient

Description

This function will generate a number of random graphs, calculate their rich club coefficients ($\phi$), and return $\phi$ of the graph of interest divided by the mean across random graphs, i.e. $\phi_{norm}$. If random graphs have already been generated, you can supply a list as an argument (since graph generation is time consuming).

Usage

rich.club.norm(g, N = 100, rand = NULL, ...)

Arguments

g
The igraph graph object of interest
N
The number of random graphs to generate (default: 100)
rand
A list of igraph graph objects, if random graphs have already been generated (default: NULL)
...
Other parameters (passed to rich.club.coeff)

Value

  • A list with two elements:
  • phi.randA matrix with N rows and max(degree(g)) columns, where each row contains the coefficients for a given random graph.
  • phi.origA vector of the rich-club coefficients for the original graph.
  • phi.normA named vector of the normalized rich club coefficients.
  • pThe p-value based on the N random graphs generated.

References

Colizza V., Flammini A., Serrano M.A., Vespignani A. (2006) Detecting rich-club ordering in complex networks. Nature Physics, 2:110-115.

See Also

rich.club.coeff, sim.rand.graph.par